# notebook-template
Repository for analysis notebook template development.

The objective of this repository is to converge on a Jupyter Notebook style that is common to the MDTF, MAR, and internal NCAR and GFDL analysis workflows.  This is an ambitious endeavor that will require on finding the common ground across all of the approaches while focusing on making the user experience lightweight and intuitive.

## Structure of the repository
* `inspirations/`: This directory houses working examples of inspiration for how different groups are approaching the notebook construction.
* (more notes added as needed)

## Standards
The final converged notebook should make use of established standards and conventions as much as possible.

[Link to EMDS Standards](https://github.com/Earth-System-Diagnostics-Standards/EMDS/blob/main/standards.md)